@@ -1,7 +1,6 @@
 from typing import Dict, List
 
 from social_distancing_sim.agent.agent_base import AgentBase
-from social_distancing_sim.environment.observation_space import ObservationSpace
 
 
 class RandomAgent(AgentBase):
@@ -11,9 +10,10 @@ class RandomAgent(AgentBase):
     It doesn't support reconnection action, as this breaks on connected nodes - this is a good error check so will stay
     as it is for now.
     """
-    @property
-    def available_actions(self) -> List[str]:
-        return ['vaccinate', 'isolate']
 
-    def select_actions(self, obs: ObservationSpace) -> Dict[int, str]:
-        return self.sample(obs)
+    @property
+    def available_actions(self) -> List[int]:
+        return [1, 2]
+
+    def _select_actions_targets(self) -> Dict[int, int]:
+        return self.sample()
